==> hybrid-rsa-aes-0.2.1.tar.gz: hybrid-rsa-aes-0.2.1/setup.py <==
#!/usr/bin/env python
import pathlib
from importlib.machinery import SourceFileLoader

from setuptools import find_packages, setup

version = SourceFileLoader("version", "hybrid_rsa_aes/version.py").load_module()


_ROOT = pathlib.Path(__file__).parent

with open(str(_ROOT / "README.rst")) as f:
    readme = f.read()

CLASSIFIERS = [
    "Development Status :: 5 - Production/Stable",
    "Programming Language :: Python :: 3 :: Only",
    "Programming Language :: Python :: 3.7",
    "Programming Language :: Python :: 3.8",
    "Programming Language :: Python :: 3.9",
    "Operating System :: POSIX",
    "Topic :: System :: Networking",
    "Topic :: Software Development",
    "Topic :: Software Development :: Libraries",
    "Environment :: Console",
    "Intended Audience :: Developers",
]


setup(
    name="hybrid-rsa-aes",
    version=str(version.VERSION),
    license="Apache License, Version 2.0",
    description="Helper for hybrid AES-RSA encryption",
    long_description=readme,
    long_description_content_type="text/x-rst",
    author="Pavel Liashkov",
    author_email="pavel.liashkov@protonmail.com",
    maintainer="Pavel Liashkov",
    maintainer_email="pavel.liashkov@protonmail.com",
    download_url="https://pypi.python.org/pypi/hybrid-rsa-aes",
    url="https://github.com/bigbag/hybrid-rsa-aes",
    platforms=["POSIX"],
    classifiers=CLASSIFIERS,
    python_requires=">=3.7",
    install_requires=["cryptography==3.3.1"],
    packages=find_packages(),
    include_package_data=True,
    zip_safe=False,
    test_suite="",
)

==> hybrid-rsa-aes-0.2.2.tar.gz: hybrid-rsa-aes-0.2.2/setup.py <==
#!/usr/bin/env python
import pathlib
from importlib.machinery import SourceFileLoader

from setuptools import find_packages, setup

version = SourceFileLoader("version", "hybrid_rsa_aes/version.py").load_module()


_ROOT = pathlib.Path(__file__).parent

with open(str(_ROOT / "README.md")) as f:
    readme = f.read()

CLASSIFIERS = [
    "Development Status :: 5 - Production/Stable",
    "Programming Language :: Python :: 3 :: Only",
    "Programming Language :: Python :: 3.7",
    "Programming Language :: Python :: 3.8",
    "Programming Language :: Python :: 3.9",
    "Operating System :: POSIX",
    "Topic :: Software Development",
    "Topic :: Software Development :: Libraries",
    "Environment :: Console",
    "Intended Audience :: Developers",
]


setup(
    name="hybrid-rsa-aes",
    version=str(version.VERSION),
    license="Apache License, Version 2.0",
    description="Helper for hybrid AES-RSA encryption",
    long_description=readme,
    long_description_content_type="text/markdown",
    author="Pavel Liashkov",
    author_email="pavel.liashkov@protonmail.com",
    maintainer="Pavel Liashkov",
    maintainer_email="pavel.liashkov@protonmail.com",
    download_url="https://pypi.python.org/pypi/hybrid-rsa-aes",
    url="https://github.com/bigbag/hybrid-rsa-aes",
    platforms=["POSIX"],
    classifiers=CLASSIFIERS,
    python_requires=">=3.7",
    install_requires=["cryptography==3.3.1"],
    packages=find_packages(),
    include_package_data=True,
    zip_safe=False,
    test_suite="",
)
